pub struct GetAtHomeServer<'a> {
pub chapter_id: &'a Uuid,
pub force_port443: bool,
}Expand description
Get MangaDex@Home server URL
Call to `GET /at-home/server/{chapterId}
Fields
chapter_id: &'a UuidChapter ID
force_port443: boolForce selecting from MangaDex@Home servers that use the standard HTTPS port 443.
While the conventional port for HTTPS traffic is 443 and servers are encouraged to use it, it is not a hard requirement as it technically isn’t anything special.
However, some misbehaving school/office network will at time block traffic to non-standard ports, and setting this flag to true will ensure selection of a server that uses these.
Implementations